@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.devtools.cloudbuild_v1.services.cloud_build import pagers
@@ -189,11 +191,11 @@ class CloudBuildAsyncClient:
 
     async def create_build(
         self,
-        request: cloudbuild.CreateBuildRequest = None,
+        request: Union[cloudbuild.CreateBuildRequest, dict] = None,
         *,
         project_id: str = None,
         build: cloudbuild.Build = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -204,7 +206,7 @@ class CloudBuildAsyncClient:
         build status (such as ``SUCCESS`` or ``FAILURE``).
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateBuildRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateBuildRequest, dict]):
                 The request object. Request to create a new build.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -227,8 +229,8 @@ class CloudBuildAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -296,11 +298,11 @@ class CloudBuildAsyncClient:
 
     async def get_build(
         self,
-        request: cloudbuild.GetBuildRequest = None,
+        request: Union[cloudbuild.GetBuildRequest, dict] = None,
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.Build:
@@ -311,7 +313,7 @@ class CloudBuildAsyncClient:
         information.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetBuildRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.GetBuildRequest, dict]):
                 The request object. Request to get a build.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -401,11 +403,11 @@ class CloudBuildAsyncClient:
 
     async def list_builds(
         self,
-        request: cloudbuild.ListBuildsRequest = None,
+        request: Union[cloudbuild.ListBuildsRequest, dict] = None,
         *,
         project_id: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBuildsAsyncPager:
@@ -414,7 +416,7 @@ class CloudBuildAsyncClient:
         may have finished successfully or unsuccessfully.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListBuildsRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.ListBuildsRequest, dict]):
                 The request object. Request to list builds.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -493,18 +495,18 @@ class CloudBuildAsyncClient:
 
     async def cancel_build(
         self,
-        request: cloudbuild.CancelBuildRequest = None,
+        request: Union[cloudbuild.CancelBuildRequest, dict] = None,
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.Build:
         r"""Cancels a build in progress.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CancelBuildRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.CancelBuildRequest, dict]):
                 The request object. Request to cancel an ongoing build.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -584,11 +586,11 @@ class CloudBuildAsyncClient:
 
     async def retry_build(
         self,
-        request: cloudbuild.RetryBuildRequest = None,
+        request: Union[cloudbuild.RetryBuildRequest, dict] = None,
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -624,7 +626,7 @@ class CloudBuildAsyncClient:
            settings.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.RetryBuildRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.RetryBuildRequest, dict]):
                 The request object. Specifies a build to retry.
             project_id (:class:`str`):
                 Required. ID of the project.
@@ -649,8 +651,8 @@ class CloudBuildAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -718,11 +720,11 @@ class CloudBuildAsyncClient:
 
     async def approve_build(
         self,
-        request: cloudbuild.ApproveBuildRequest = None,
+        request: Union[cloudbuild.ApproveBuildRequest, dict] = None,
         *,
         name: str = None,
         approval_result: cloudbuild.ApprovalResult = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -733,7 +735,7 @@ class CloudBuildAsyncClient:
         If rejected, the returned LRO will be immediately done.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ApproveBuildRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.ApproveBuildRequest, dict]):
                 The request object. Request to approve or reject a
                 pending build.
             name (:class:`str`):
@@ -759,8 +761,8 @@ class CloudBuildAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -834,11 +836,11 @@ class CloudBuildAsyncClient:
 
     async def create_build_trigger(
         self,
-        request: cloudbuild.CreateBuildTriggerRequest = None,
+        request: Union[cloudbuild.CreateBuildTriggerRequest, dict] = None,
         *,
         project_id: str = None,
         trigger: cloudbuild.BuildTrigger = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -847,7 +849,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateBuildTriggerRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateBuildTriggerRequest, dict]):
                 The request object. Request to create a new
                 `BuildTrigger`.
             project_id (:class:`str`):
@@ -910,11 +912,11 @@ class CloudBuildAsyncClient:
 
     async def get_build_trigger(
         self,
-        request: cloudbuild.GetBuildTriggerRequest = None,
+        request: Union[cloudbuild.GetBuildTriggerRequest, dict] = None,
         *,
         project_id: str = None,
         trigger_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -923,7 +925,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetBuildTriggerRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.GetBuildTriggerRequest, dict]):
                 The request object. Returns the `BuildTrigger` with the
                 specified ID.
             project_id (:class:`str`):
@@ -998,10 +1000,10 @@ class CloudBuildAsyncClient:
 
     async def list_build_triggers(
         self,
-        request: cloudbuild.ListBuildTriggersRequest = None,
+        request: Union[cloudbuild.ListBuildTriggersRequest, dict] = None,
         *,
         project_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBuildTriggersAsyncPager:
@@ -1010,7 +1012,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListBuildTriggersRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.ListBuildTriggersRequest, dict]):
                 The request object. Request to list existing
                 `BuildTriggers`.
             project_id (:class:`str`):
@@ -1083,11 +1085,11 @@ class CloudBuildAsyncClient:
 
     async def delete_build_trigger(
         self,
-        request: cloudbuild.DeleteBuildTriggerRequest = None,
+        request: Union[cloudbuild.DeleteBuildTriggerRequest, dict] = None,
         *,
         project_id: str = None,
         trigger_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1096,7 +1098,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.DeleteBuildTriggerRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.DeleteBuildTriggerRequest, dict]):
                 The request object. Request to delete a `BuildTrigger`.
             project_id (:class:`str`):
                 Required. ID of the project that owns
@@ -1160,12 +1162,12 @@ class CloudBuildAsyncClient:
 
     async def update_build_trigger(
         self,
-        request: cloudbuild.UpdateBuildTriggerRequest = None,
+        request: Union[cloudbuild.UpdateBuildTriggerRequest, dict] = None,
         *,
         project_id: str = None,
         trigger_id: str = None,
         trigger: cloudbuild.BuildTrigger = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -1174,7 +1176,7 @@ class CloudBuildAsyncClient:
         This API is experimental.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.UpdateBuildTriggerRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.UpdateBuildTriggerRequest, dict]):
                 The request object. Request to update an existing
                 `BuildTrigger`.
             project_id (:class:`str`):
@@ -1244,19 +1246,19 @@ class CloudBuildAsyncClient:
 
     async def run_build_trigger(
         self,
-        request: cloudbuild.RunBuildTriggerRequest = None,
+        request: Union[cloudbuild.RunBuildTriggerRequest, dict] = None,
         *,
         project_id: str = None,
         trigger_id: str = None,
         source: cloudbuild.RepoSource = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Runs a ``BuildTrigger`` at a particular source revision.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.RunBuildTriggerRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.RunBuildTriggerRequest, dict]):
                 The request object. Specifies a build trigger to run and
                 the source to use.
             project_id (:class:`str`):
@@ -1285,8 +1287,8 @@ class CloudBuildAsyncClient:
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -1356,9 +1358,9 @@ class CloudBuildAsyncClient:
 
     async def receive_trigger_webhook(
         self,
-        request: cloudbuild.ReceiveTriggerWebhookRequest = None,
+        request: Union[cloudbuild.ReceiveTriggerWebhookRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.ReceiveTriggerWebhookResponse:
@@ -1366,7 +1368,7 @@ class CloudBuildAsyncClient:
         receives a webhook request targeted at a specific trigger.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookRequest, dict]):
                 The request object. ReceiveTriggerWebhookRequest
                 [Experimental] is the request object accepted by the
                 ReceiveTriggerWebhook method.
@@ -1401,19 +1403,19 @@ class CloudBuildAsyncClient:
 
     async def create_worker_pool(
         self,
-        request: cloudbuild.CreateWorkerPoolRequest = None,
+        request: Union[cloudbuild.CreateWorkerPoolRequest, dict] = None,
         *,
         parent: str = None,
         worker_pool: cloudbuild.WorkerPool = None,
         worker_pool_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a ``WorkerPool``.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest, dict]):
                 The request object. Request to create a new
                 `WorkerPool`.
             parent (:class:`str`):
@@ -1520,17 +1522,17 @@ class CloudBuildAsyncClient:
 
     async def get_worker_pool(
         self,
-        request: cloudbuild.GetWorkerPoolRequest = None,
+        request: Union[cloudbuild.GetWorkerPoolRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.WorkerPool:
         r"""Returns details of a ``WorkerPool``.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest, dict]):
                 The request object. Request to get a `WorkerPool` with
                 the specified name.
             name (:class:`str`):
@@ -1615,17 +1617,17 @@ class CloudBuildAsyncClient:
 
     async def delete_worker_pool(
         self,
-        request: cloudbuild.DeleteWorkerPoolRequest = None,
+        request: Union[cloudbuild.DeleteWorkerPoolRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a ``WorkerPool``.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest, dict]):
                 The request object. Request to delete a `WorkerPool`.
             name (:class:`str`):
                 Required. The name of the ``WorkerPool`` to delete.
@@ -1707,18 +1709,18 @@ class CloudBuildAsyncClient:
 
     async def update_worker_pool(
         self,
-        request: cloudbuild.UpdateWorkerPoolRequest = None,
+        request: Union[cloudbuild.UpdateWorkerPoolRequest, dict] = None,
         *,
         worker_pool: cloudbuild.WorkerPool = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates a ``WorkerPool``.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest, dict]):
                 The request object. Request to update a `WorkerPool`.
             worker_pool (:class:`google.cloud.devtools.cloudbuild_v1.types.WorkerPool`):
                 Required. The ``WorkerPool`` to update.
@@ -1817,17 +1819,17 @@ class CloudBuildAsyncClient:
 
     async def list_worker_pools(
         self,
-        request: cloudbuild.ListWorkerPoolsRequest = None,
+        request: Union[cloudbuild.ListWorkerPoolsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListWorkerPoolsAsyncPager:
         r"""Lists ``WorkerPool``\ s.
 
         Args:
-            request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest`):
+            request (Union[google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest, dict]):
                 The request object. Request to list `WorkerPool`\s.
             parent (:class:`str`):
                 Required. The parent of the collection of
@@ -1913,9 +1915,7 @@ class CloudBuildAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-devtools-cloudbuild",
-        ).version,
+        gapic_version=pkg_resources.get_distribution("google-cloud-build",).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
