@@ -30,6 +30,8 @@ from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.devtools.cloudbuild_v1.services.cloud_build import pagers
@@ -478,7 +480,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         build: cloudbuild.Build = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -512,8 +514,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -585,7 +587,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.Build:
@@ -680,7 +682,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBuildsPager:
@@ -762,7 +764,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.Build:
@@ -853,7 +855,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -914,8 +916,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -987,7 +989,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         name: str = None,
         approval_result: cloudbuild.ApprovalResult = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1024,8 +1026,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -1103,7 +1105,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         trigger: cloudbuild.BuildTrigger = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -1179,7 +1181,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         trigger_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -1256,7 +1258,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         request: Union[cloudbuild.ListBuildTriggersRequest, dict] = None,
         *,
         project_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListBuildTriggersPager:
@@ -1332,7 +1334,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         project_id: str = None,
         trigger_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -1400,7 +1402,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         project_id: str = None,
         trigger_id: str = None,
         trigger: cloudbuild.BuildTrigger = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.BuildTrigger:
@@ -1484,7 +1486,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         project_id: str = None,
         trigger_id: str = None,
         source: cloudbuild.RepoSource = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1520,8 +1522,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 An object representing a long-running operation.
 
                 The result type for the operation will be
-                :class:`google.cloud.devtools.cloudbuild_v1.types.Build` A
-                build resource in the Cloud Build API.
+                :class:`google.cloud.devtools.cloudbuild_v1.types.Build`
+                A build resource in the Cloud Build API.
 
                    At a high level, a Build describes where to find
                    source code, how to build it (for example, the
@@ -1593,7 +1595,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         self,
         request: Union[cloudbuild.ReceiveTriggerWebhookRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.ReceiveTriggerWebhookResponse:
@@ -1642,7 +1644,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         parent: str = None,
         worker_pool: cloudbuild.WorkerPool = None,
         worker_pool_id: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1759,7 +1761,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         request: Union[cloudbuild.GetWorkerPoolRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> cloudbuild.WorkerPool:
@@ -1844,7 +1846,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         request: Union[cloudbuild.DeleteWorkerPoolRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -1937,7 +1939,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         *,
         worker_pool: cloudbuild.WorkerPool = None,
         update_mask: field_mask_pb2.FieldMask = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation.Operation:
@@ -2046,7 +2048,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         request: Union[cloudbuild.ListWorkerPoolsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListWorkerPoolsPager:
@@ -2136,9 +2138,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-devtools-cloudbuild",
-        ).version,
+        gapic_version=pkg_resources.get_distribution("google-cloud-build",).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
