@@ -152,6 +152,13 @@ class StorageSource(proto.Message):
 class RepoSource(proto.Message):
     r"""Location of the source in a Google Cloud Source Repository.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         project_id (str):
             ID of the project that owns the Cloud Source
@@ -164,13 +171,16 @@ class RepoSource(proto.Message):
             The syntax of the regular expressions accepted
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
+            This field is a member of `oneof`_ ``revision``.
         tag_name (str):
             Regex matching tags to build.
             The syntax of the regular expressions accepted
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
+            This field is a member of `oneof`_ ``revision``.
         commit_sha (str):
             Explicit commit SHA to build.
+            This field is a member of `oneof`_ ``revision``.
         dir_ (str):
             Directory, relative to the source root, in which to run the
             build.
@@ -224,17 +234,27 @@ class StorageSourceManifest(proto.Message):
 class Source(proto.Message):
     r"""Location of the source in a supported storage service.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         storage_source (google.cloud.devtools.cloudbuild_v1.types.StorageSource):
             If provided, get the source from this
             location in Google Cloud Storage.
+            This field is a member of `oneof`_ ``source``.
         repo_source (google.cloud.devtools.cloudbuild_v1.types.RepoSource):
             If provided, get the source from this
             location in a Cloud Source Repository.
+            This field is a member of `oneof`_ ``source``.
         storage_source_manifest (google.cloud.devtools.cloudbuild_v1.types.StorageSourceManifest):
             If provided, get the source from this manifest in Google
             Cloud Storage. This feature is in Preview; see description
             `here <https://github.com/GoogleCloudPlatform/cloud-builders/tree/master/gcs-fetcher>`__.
+            This field is a member of `oneof`_ ``source``.
     """
 
     storage_source = proto.Field(
@@ -1158,6 +1178,13 @@ class BuildTrigger(proto.Message):
     r"""Configuration for an automated build in response to source
     repository changes.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         resource_name (str):
             The ``Trigger`` name with format:
@@ -1211,11 +1238,14 @@ class BuildTrigger(proto.Message):
 
             Currently only available for GitHub App
             Triggers.
+            This field is a member of `oneof`_ ``build_template``.
         build (google.cloud.devtools.cloudbuild_v1.types.Build):
             Contents of the build template.
+            This field is a member of `oneof`_ ``build_template``.
         filename (str):
             Path, from the source root, to the build
             configuration file (i.e. cloudbuild.yaml).
+            This field is a member of `oneof`_ ``build_template``.
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time when the trigger was
             created.
@@ -1288,6 +1318,13 @@ class GitHubEventsConfig(proto.Message):
     that creates a build whenever a GitHub event is received.
     This message is experimental.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         installation_id (int):
             The installationID that emits the GitHub
@@ -1304,9 +1341,11 @@ class GitHubEventsConfig(proto.Message):
             builders is "cloud-builders".
         pull_request (google.cloud.devtools.cloudbuild_v1.types.PullRequestFilter):
             filter to match changes in pull requests.
+            This field is a member of `oneof`_ ``event``.
         push (google.cloud.devtools.cloudbuild_v1.types.PushFilter):
             filter to match changes in refs like
             branches, tags.
+            This field is a member of `oneof`_ ``event``.
     """
 
     installation_id = proto.Field(proto.INT64, number=1,)
@@ -1360,10 +1399,14 @@ class WebhookConfig(proto.Message):
     creates a build whenever a webhook is sent to a trigger's
     webhook URL.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         secret (str):
             Required. Resource name for the secret
             required as a URL parameter.
+            This field is a member of `oneof`_ ``auth_method``.
         state (google.cloud.devtools.cloudbuild_v1.types.WebhookConfig.State):
             Potential issues with the underlying Pub/Sub
             subscription configuration. Only populated on
@@ -1386,12 +1429,16 @@ class PullRequestFilter(proto.Message):
     r"""PullRequestFilter contains filter properties for matching
     GitHub Pull Requests.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         branch (str):
             Regex of branches to match.
             The syntax of the regular expressions accepted
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
+            This field is a member of `oneof`_ ``git_ref``.
         comment_control (google.cloud.devtools.cloudbuild_v1.types.PullRequestFilter.CommentControl):
             Configure builds to run whether a repository owner or
             collaborator need to comment ``/gcbrun``.
@@ -1415,17 +1462,26 @@ class PushFilter(proto.Message):
     r"""Push contains filter properties for matching GitHub git
     pushes.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         branch (str):
             Regexes matching branches to build.
             The syntax of the regular expressions accepted
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
+            This field is a member of `oneof`_ ``git_ref``.
         tag (str):
             Regexes matching tags to build.
             The syntax of the regular expressions accepted
             is the syntax accepted by RE2 and described at
             https://github.com/google/re2/wiki/Syntax
+            This field is a member of `oneof`_ ``git_ref``.
         invert_regex (bool):
             When true, only trigger a build if the revision regex does
             NOT match the git_ref regex.
@@ -1758,6 +1814,9 @@ class WorkerPool(proto.Message):
     pools
     overview <https://cloud.google.com/build/docs/private-pools/private-pools-overview>`__.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Output only. The resource name of the ``WorkerPool``, with
@@ -1790,6 +1849,7 @@ class WorkerPool(proto.Message):
             Output only. ``WorkerPool`` state.
         private_pool_v1_config (google.cloud.devtools.cloudbuild_v1.types.PrivatePoolV1Config):
             Private Pool using a v1 configuration.
+            This field is a member of `oneof`_ ``config``.
         etag (str):
             Output only. Checksum computed by the server.
             May be sent on update and delete requests to
